@@ -11,7 +11,7 @@ This module implements the pkgbuild interface
 '''
 
 # Import python libs
-from __future__ import absolute_import, print_function
+from __future__ import absolute_import, print_function, unicode_literals
 import errno
 import logging
 import os
@@ -23,9 +23,15 @@ import traceback
 import functools
 
 # Import salt libs
-from salt.ext.six.moves.urllib.parse import urlparse as _urlparse  # pylint: disable=no-name-in-module,import-error
 from salt.exceptions import SaltInvocationError
-import salt.utils
+import salt.utils.files
+import salt.utils.path
+import salt.utils.user
+import salt.utils.vt
+
+# Import 3rd-party libs
+from salt.ext import six
+from salt.ext.six.moves.urllib.parse import urlparse as _urlparse  # pylint: disable=no-name-in-module,import-error
 
 HAS_LIBS = False
 
@@ -48,7 +54,7 @@ def __virtual__():
     missing_util = False
     utils_reqd = ['gpg', 'rpm', 'rpmbuild', 'mock', 'createrepo']
     for named_util in utils_reqd:
-        if not salt.utils.which(named_util):
+        if not salt.utils.path.which(named_util):
             missing_util = True
             break
 
@@ -76,9 +82,13 @@ def _create_rpmmacros():
         os.makedirs(mockdir)
 
     rpmmacros = os.path.join(home, '.rpmmacros')
-    with salt.utils.fopen(rpmmacros, 'w') as afile:
-        afile.write('%_topdir {0}\n'.format(rpmbuilddir))
+    with salt.utils.files.fopen(rpmmacros, 'w') as afile:
+        afile.write(
+            salt.utils.stringutils.to_str('%_topdir {0}\n'.format(rpmbuilddir))
+        )
         afile.write('%signature gpg\n')
+        afile.write('%_source_filedigest_algorithm 8\n')
+        afile.write('%_binary_filedigest_algorithm 8\n')
         afile.write('%_gpg_name packaging@saltstack.com\n')
 
 
@@ -128,7 +138,7 @@ def _get_distset(tgt):
     tgtattrs = tgt.split('-')
     if tgtattrs[0] == 'amzn':
         distset = '--define "dist .{0}1"'.format(tgtattrs[0])
-    elif tgtattrs[1] in ['5', '6', '7']:
+    elif tgtattrs[1] in ['6', '7']:
         distset = '--define "dist .el{0}"'.format(tgtattrs[1])
     else:
         distset = ''
@@ -173,17 +183,24 @@ def make_src_pkg(dest_dir, spec, sources, env=None, template=None, saltenv='base
 
     This example command should build the libnacl SOURCE package and place it in
     /var/www/html/ on the minion
+
+    .. versionchanged:: 2017.7.0
+
+    .. note::
+
+        using SHA256 as digest and minimum level dist el6
+
     '''
     _create_rpmmacros()
     tree_base = _mk_tree()
     spec_path = _get_spec(tree_base, spec, template, saltenv)
-    if isinstance(sources, str):
+    if isinstance(sources, six.string_types):
         sources = sources.split(',')
     for src in sources:
         _get_src(tree_base, src, saltenv)
 
-    # make source rpms for dist el5, usable with mock on other dists
-    cmd = 'rpmbuild --define "_topdir {0}" -bs --define "_source_filedigest_algorithm md5" --define "_binary_filedigest_algorithm md5" --define "dist .el5" {1}'.format(tree_base, spec_path)
+    # make source rpms for dist el6 with SHA256, usable with mock on other dists
+    cmd = 'rpmbuild --verbose --define "_topdir {0}" -bs --define "dist .el6" {1}'.format(tree_base, spec_path)
     __salt__['cmd.run'](cmd)
     srpms = os.path.join(tree_base, 'SRPMS')
     ret = []
@@ -291,7 +308,7 @@ def build(runas,
                     shutil.copy(full, log_file)
                     ret.setdefault('Log Files', []).append(log_file)
         except Exception as exc:
-            log.error('Error building from {0}: {1}'.format(srpm, exc))
+            log.error('Error building from %s: %s', srpm, exc)
         finally:
             shutil.rmtree(results_dir)
     shutil.rmtree(deps_dir)
@@ -472,7 +489,7 @@ def make_repo(repodir,
                 times_looped = 0
                 error_msg = 'Failed to sign file {0}'.format(abs_file)
                 cmd = 'rpm {0} --addsign {1}'.format(define_gpg_name, abs_file)
-                preexec_fn = functools.partial(salt.utils.chugid_and_umask, runas, None)
+                preexec_fn = functools.partial(salt.utils.user.chugid_and_umask, runas, None)
                 try:
                     stdout, stderr = None, None
                     proc = salt.utils.vt.Terminal(
