@@ -3,12 +3,13 @@
 Classes for working with Windows Update Agent
 '''
 # Import Python libs
-from __future__ import absolute_import
+from __future__ import absolute_import, print_function, unicode_literals
 import logging
 import subprocess
 
 # Import Salt libs
-import salt.utils
+import salt.utils.args
+import salt.utils.data
 from salt.ext import six
 from salt.ext.six.moves import range
 from salt.exceptions import CommandExecutionError
@@ -134,7 +135,7 @@ class Updates(object):
 
             results[update.Identity.UpdateID] = {
                 'guid': update.Identity.UpdateID,
-                'Title': str(update.Title),
+                'Title': six.text_type(update.Title),
                 'Type': self.update_types[update.Type],
                 'Description': update.Description,
                 'Downloaded': bool(update.IsDownloaded),
@@ -142,7 +143,7 @@ class Updates(object):
                 'Mandatory': bool(update.IsMandatory),
                 'EULAAccepted': bool(update.EulaAccepted),
                 'NeedsReboot': bool(update.RebootRequired),
-                'Severity': str(update.MsrcSeverity),
+                'Severity': six.text_type(update.MsrcSeverity),
                 'UserInput':
                     bool(update.InstallationBehavior.CanRequestUserInput),
                 'RebootBehavior':
@@ -198,17 +199,17 @@ class Updates(object):
             results['Total'] += 1
 
             # Updates available for download
-            if not salt.utils.is_true(update.IsDownloaded) \
-                    and not salt.utils.is_true(update.IsInstalled):
+            if not salt.utils.data.is_true(update.IsDownloaded) \
+                    and not salt.utils.data.is_true(update.IsInstalled):
                 results['Available'] += 1
 
             # Updates downloaded awaiting install
-            if salt.utils.is_true(update.IsDownloaded) \
-                    and not salt.utils.is_true(update.IsInstalled):
+            if salt.utils.data.is_true(update.IsDownloaded) \
+                    and not salt.utils.data.is_true(update.IsInstalled):
                 results['Downloaded'] += 1
 
             # Updates installed
-            if salt.utils.is_true(update.IsInstalled):
+            if salt.utils.data.is_true(update.IsInstalled):
                 results['Installed'] += 1
 
             # Add Categories and increment total for each one
@@ -337,7 +338,7 @@ class WindowsUpdateAgent(object):
         try:
             results = searcher.Search(search_string)
             if results.Updates.Count == 0:
-                log.debug('No Updates found for:\n\t\t{0}'.format(search_string))
+                log.debug('No Updates found for:\n\t\t%s', search_string)
                 return 'No Updates found: {0}'.format(search_string)
         except pywintypes.com_error as error:
             # Something happened, raise an error
@@ -347,8 +348,7 @@ class WindowsUpdateAgent(object):
             except KeyError:
                 failure_code = 'Unknown Failure: {0}'.format(error)
 
-            log.error('Search Failed: {0}\n\t\t{1}'.format(
-                failure_code, search_string))
+            log.error('Search Failed: %s\n\t\t%s', failure_code, search_string)
             raise CommandExecutionError(failure_code)
 
         self._updates = results.Updates
@@ -436,16 +436,16 @@ class WindowsUpdateAgent(object):
 
         for update in self._updates:
 
-            if salt.utils.is_true(update.IsHidden) and skip_hidden:
+            if salt.utils.data.is_true(update.IsHidden) and skip_hidden:
                 continue
 
-            if salt.utils.is_true(update.IsInstalled) and skip_installed:
+            if salt.utils.data.is_true(update.IsInstalled) and skip_installed:
                 continue
 
-            if salt.utils.is_true(update.IsMandatory) and skip_mandatory:
+            if salt.utils.data.is_true(update.IsMandatory) and skip_mandatory:
                 continue
 
-            if salt.utils.is_true(
+            if salt.utils.data.is_true(
                     update.InstallationBehavior.RebootBehavior) and skip_reboot:
                 continue
 
@@ -509,7 +509,7 @@ class WindowsUpdateAgent(object):
             search_string = [search_string]
 
         if isinstance(search_string, six.integer_types):
-            search_string = [str(search_string)]
+            search_string = [six.text_type(search_string)]
 
         for update in self._updates:
 
@@ -586,14 +586,14 @@ class WindowsUpdateAgent(object):
                 bool(update.IsDownloaded)
 
             # Accept EULA
-            if not salt.utils.is_true(update.EulaAccepted):
-                log.debug('Accepting EULA: {0}'.format(update.Title))
+            if not salt.utils.data.is_true(update.EulaAccepted):
+                log.debug('Accepting EULA: %s', update.Title)
                 update.AcceptEula()  # pylint: disable=W0104
 
             # Update already downloaded
-            if not salt.utils.is_true(update.IsDownloaded):
-                log.debug('To Be Downloaded: {0}'.format(uid))
-                log.debug('\tTitle: {0}'.format(update.Title))
+            if not salt.utils.data.is_true(update.IsDownloaded):
+                log.debug('To Be Downloaded: %s', uid)
+                log.debug('\tTitle: %s', update.Title)
                 download_list.Add(update)
 
         # Check the download list
@@ -617,7 +617,7 @@ class WindowsUpdateAgent(object):
             except KeyError:
                 failure_code = 'Unknown Failure: {0}'.format(error)
 
-            log.error('Download Failed: {0}'.format(failure_code))
+            log.error('Download Failed: %s', failure_code)
             raise CommandExecutionError(failure_code)
 
         # Lookup dictionary
@@ -696,9 +696,9 @@ class WindowsUpdateAgent(object):
             ret['Updates'][uid]['AlreadyInstalled'] = bool(update.IsInstalled)
 
             # Make sure the update has actually been installed
-            if not salt.utils.is_true(update.IsInstalled):
-                log.debug('To Be Installed: {0}'.format(uid))
-                log.debug('\tTitle: {0}'.format(update.Title))
+            if not salt.utils.data.is_true(update.IsInstalled):
+                log.debug('To Be Installed: %s', uid)
+                log.debug('\tTitle: %s', update.Title)
                 install_list.Add(update)
 
         # Check the install list
@@ -723,7 +723,7 @@ class WindowsUpdateAgent(object):
             except KeyError:
                 failure_code = 'Unknown Failure: {0}'.format(error)
 
-            log.error('Install Failed: {0}'.format(failure_code))
+            log.error('Install Failed: %s', failure_code)
             raise CommandExecutionError(failure_code)
 
         # Lookup dictionary
@@ -741,7 +741,7 @@ class WindowsUpdateAgent(object):
         if result.ResultCode in [2, 3]:
             ret['Success'] = True
             ret['NeedsReboot'] = result.RebootRequired
-            log.debug('NeedsReboot: {0}'.format(result.RebootRequired))
+            log.debug('NeedsReboot: %s', result.RebootRequired)
         else:
             log.debug('Install Failed')
             ret['Success'] = False
@@ -816,9 +816,9 @@ class WindowsUpdateAgent(object):
                 not bool(update.IsInstalled)
 
             # Make sure the update has actually been Uninstalled
-            if salt.utils.is_true(update.IsInstalled):
-                log.debug('To Be Uninstalled: {0}'.format(uid))
-                log.debug('\tTitle: {0}'.format(update.Title))
+            if salt.utils.data.is_true(update.IsInstalled):
+                log.debug('To Be Uninstalled: %s', uid)
+                log.debug('\tTitle: %s', update.Title)
                 uninstall_list.Add(update)
 
         # Check the install list
@@ -878,10 +878,10 @@ class WindowsUpdateAgent(object):
 
                 except CommandExecutionError as exc:
                     log.debug('Uninstall using DISM failed')
-                    log.debug('Command: {0}'.format(' '.join(cmd)))
-                    log.debug('Error: {0}'.format(str(exc)))
-                    raise CommandExecutionError('Uninstall using DISM failed:'
-                                                '{0}'.format(str(exc)))
+                    log.debug('Command: %s', ' '.join(cmd))
+                    log.debug('Error: %s', exc)
+                    raise CommandExecutionError(
+                        'Uninstall using DISM failed: {0}'.format(exc))
 
                 # DISM Uninstall Completed Successfully
                 log.debug('Uninstall Completed using DISM')
@@ -890,7 +890,7 @@ class WindowsUpdateAgent(object):
                 ret['Success'] = True
                 ret['Message'] = 'Uninstalled using DISM'
                 ret['NeedsReboot'] = needs_reboot()
-                log.debug('NeedsReboot: {0}'.format(ret['NeedsReboot']))
+                log.debug('NeedsReboot: %s', ret['NeedsReboot'])
 
                 # Refresh the Updates Table
                 self.refresh()
@@ -916,7 +916,7 @@ class WindowsUpdateAgent(object):
                 return ret
 
             # Found a differenct exception, Raise error
-            log.error('Uninstall Failed: {0}'.format(failure_code))
+            log.error('Uninstall Failed: %s', failure_code)
             raise CommandExecutionError(failure_code)
 
         # Lookup dictionary
@@ -934,7 +934,7 @@ class WindowsUpdateAgent(object):
         if result.ResultCode in [2, 3]:
             ret['Success'] = True
             ret['NeedsReboot'] = result.RebootRequired
-            log.debug('NeedsReboot: {0}'.format(result.RebootRequired))
+            log.debug('NeedsReboot: %s', result.RebootRequired)
         else:
             log.debug('Uninstall Failed')
             ret['Success'] = False
@@ -963,7 +963,7 @@ class WindowsUpdateAgent(object):
         '''
 
         if isinstance(cmd, six.string_types):
-            cmd = salt.utils.shlex_split(cmd)
+            cmd = salt.utils.args.shlex_split(cmd)
 
         try:
             log.debug(cmd)
@@ -975,8 +975,8 @@ class WindowsUpdateAgent(object):
             return p.communicate()
 
         except (OSError, IOError) as exc:
-            log.debug('Command Failed: {0}'.format(' '.join(cmd)))
-            log.debug('Error: {0}'.format(str(exc)))
+            log.debug('Command Failed: %s', ' '.join(cmd))
+            log.debug('Error: %s', exc)
             raise CommandExecutionError(exc)
 
 
@@ -1002,4 +1002,4 @@ def needs_reboot():
 
     # Create an AutoUpdate object
     obj_sys = win32com.client.Dispatch('Microsoft.Update.SystemInfo')
-    return salt.utils.is_true(obj_sys.RebootRequired)
+    return salt.utils.data.is_true(obj_sys.RebootRequired)
